#!/bin/sh

# THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
# 5724-I04 (C) COPYRIGHT International Business Machines Corp., 1997,2007
# All Rights Reserved * Licensed Materials - Property of IBM
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.

# ifix launcher
thisHostname=`hostname -s`
thisDir=`dirname "$0"`
errorsduringinstall=0

if [ ! "$2" ] 
then
  if [  -f ./LI72432.sh ]
 then
 echo "Ifix_LI72432: WVS Ifix LI72432 Installer command syntax: "
 echo "  "
 echo " to install ifix  syntax: ifix_LI72432.sh  -install "
 echo "  "
 echo " to uninstall ifix  syntax: ifix_LI72432.sh -uninstall "
 echo " "
 exit -1
 fi
fi

if [ $# -eq 0 ]
then
 echo "Ifix_LI72432: WVS Ifix LI72432 Installer command syntax: "
 echo " to install ifix  syntax: ifix_LI72432 -install "
 echo "  "
 echo " to uninstall ifix  syntax: ifix_LI72432.sh -uninstall "
 echo " "
 exit -1
fi

if [ -f /opt/WebSphere/AppServer/bin/setupCmdLine.sh ]
then
   . /opt/WebSphere/AppServer/bin/setupCmdLine.sh
fi
   
   
if [ ! "$WAS_HOME" ] ; then
   echo "Ifix_LI72432: Please run WebSphere Application Server's setupCmdLine.sh to setup"
   echo "         the WAS Command line environment"
  exit -1
fi

if [ ! "$WVS_ROOT" ] ; then
   echo "Ifix_LI72432: Please configure WebSphere Voice Server wvs.setenv according"
   echo "         to the WVS InfoCenter "
  exit -1
fi


isInstallOption=false
isUnInstallOption=false
nonJavaOptionCount=1
for option in "$@" ; do
  if [ "$option" = "-install" ] ; then
     isInstallOption=true
  else
     if [ "$option" = "-uninstall" ] ; then
        isUnInstallOption=true
     fi
  fi
done

if [ "$isInstallOption" = "true" ] ; then
  if [ -f $WVS_ROOT/ifix/LI72432/wvsapp.ear.bak ] ; then
    echo "Ifix_LI72432: Ifix LI72432 is applied, please uninstall before trying to reinstall ifix"
    exit -1
  fi
  if [ ! -d $WVS_ROOT/fixes/5.1.3.3 ] ; then
    echo "Ifix_IY85112: Pre-requisite Fixpack 5.1.3.3 is not applied, please install Fixpack 5.1.3.3 before trying to install ifix LI72432"
    exit -1
  fi
fi

if [ "$isInstallOption" = "true" ] ; then
 # Check that the ifix files are found
 echo "Ifix_LI72432: Checking for ifix files ..."
  if [ -f $thisDir/wvsapp.ear ] ; then
	echo "Ifix_LI72432: Ifix files found.. proceeding to install ifix"
	mkdir -p $WVS_ROOT/ifix/LI72432
	cp -p $thisDir/LI72432.sh $WVS_ROOT/ifix/ifix_LI72432.sh
	cp -p $thisDir/stopVoiceServer.jacl $WVS_ROOT/ifix/LI72432/stopVoiceServer.jacl
	cp -p $WVS_ROOT/ear/wvsapp.ear $WVS_ROOT/ifix/LI72432/wvsapp.ear.bak
	cp -p $WVS_ROOT/ViaVoice/bin/libibmgram.so $WVS_ROOT/ifix/LI72432/libibmgram.so.bak
	cp -p $WVS_ROOT/.package/installEar.jacl $WVS_ROOT/ifix/LI72432/installEar.jacl.bak

	# Backup SIV config files ----------------------------------------------------
	echo "Ifix_LI72432: Backing up SIV config files..."
	mkdir -p $WVS_ROOT/ifix/LI72432/confbck >> $WVS_ROOT/log/LI72432.log
	cp -fp $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsweb.war/WEB-INF/ibm-web-bnd.xmi $WVS_ROOT/ifix/LI72432/confbck >> $WVS_ROOT/log/LI72432.log
	cp -fp $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsweb.war/WEB-INF/web.xml $WVS_ROOT/ifix/LI72432/confbck >> $WVS_ROOT/log/LI72432.log
	cp -fp $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsejb.jar/META-INF/ibm-ejb-jar-bnd.xmi $WVS_ROOT/ifix/LI72432/confbck >> $WVS_ROOT/log/LI72432.log
	cp -fp $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsejb.jar/META-INF/ejb-jar.xml $WVS_ROOT/ifix/LI72432/confbck >> $WVS_ROOT/log/LI72432.log
	echo "Ifix_LI72432: SIV config backup complete."
	# ----------------------------------------------------------------------------

	# update collector
	echo "Ifix_IY99767: Updating the collector" >> $WVS_ROOT/log/LI72432.log
	jar uvf $WAS_HOME/lib/collector.jar com >> $WVS_ROOT/log/LI72432.log
	cp -fp $WAS_HOME/lib/collector.jar $WVS_ROOT/lib >> $WVS_ROOT/log/LI72432.log

	echo "Ifix_LI72432: Stopping WebSphere Application Server"
	$WAS_HOME/bin/stopServer.sh server1
	echo $?
	if [ "$?" = "246" -o "$?" = "0" ] ; then
	  echo "Ifix_LI72432: Application Server stopped successful, proceeding to install ifix"
	else
	  echo "Ifix_LI72432: Application Server reported failure during stopping. Ifix installation will not continue"
	  rm -rf $WVS_ROOT/ifix/LI72432
	  exit -1
	fi

	cp -fp $thisDir/wvsapp.ear $WVS_ROOT/ear/. 
	cp -fp $thisDir/libibmgram.so $WVS_ROOT/ViaVoice/bin/.
	cp -fp $thisDir/installEar.jacl $WVS_ROOT/.package/.

	echo "Ifix_LI72432: Starting WebSphere Application Server"

	echo "com.ibm.voice.server.recognizer.asr.dict.destroytimeout=1000" >> $WVS_ROOT/config/.cwvs.properties

	echo "com.ibm.voice.server.recognizer.asr.dict.fetchtimeout=1500" >> $WVS_ROOT/config/.cwvs.properties


	$WAS_HOME/bin/startServer.sh server1 -quiet
	if [ "$?" = "111" -o "$?" = "0" ] ; then
	  echo "Ifix_LI72432: Application Server started successful, proceeding to install ifix"
	else
	  echo "Ifix_LI72432: Application Server reported failure during starting. Ifix installation was not successful. Please uninstall"
	  exit -1
	fi

	echo "Ifix_LI72432: Stopping WebSphere Voice Server"
	$WAS_HOME/bin/wsadmin.sh -f $thisDir/stopVoiceServer.jacl $thisHostname
	errorsduringinstall=$?

	echo "Ifix_LI72432: Updating WebSphere Voice Server J2EE Application"
	$WAS_HOME/bin/wsadmin.sh -f $WVS_ROOT/.package/installEar.jacl $WVS_ROOT/ear wvsapp WVS5.1-$thisHostname $thisHostname
	errorsduringinstall=$?

	# Restore SIV config files ---------------------------------------------------
	echo "Ifix_LI72432: Restoring SIV config files..."
	cp -fp $WVS_ROOT/ifix/LI72432/confbck/ibm-web-bnd.xmi  $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsweb.war/WEB-INF >> $WVS_ROOT/log/LI72432.log
	cp -fp $WVS_ROOT/ifix/LI72432/confbck/web.xml $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsweb.war/WEB-INF >> $WVS_ROOT/log/LI72432.log
	cp -fp $WVS_ROOT/ifix/LI72432/confbck/ibm-ejb-jar-bnd.xmi $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsejb.jar/META-INF >> $WVS_ROOT/log/LI72432.log
	cp -fp $WVS_ROOT/ifix/LI72432/confbck/ejb-jar.xml $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsejb.jar/META-INF >> $WVS_ROOT/log/LI72432.log

	rm -rf $WVS_ROOT/ifix/LI72432/confbck >> $WVS_ROOT/log/LI72432.log
	echo "Ifix_LI72432: SIV config files restored."
	# ----------------------------------------------------------------------------

	if [ $errorsduringinstall = "0" ] ; then
		echo "Ifix_LI72432: Ifix is now applied, please reboot the system"
	else
		echo "Ifix_LI72432: Ifix installation was not successful. Please uninstall. "
	fi
  else
    echo "Ifix_LI72432: Ifix files missing, please be sure this script is in same directory as the binary files" 
  fi
  cp -fp $thisDir/LI72432.log $WVS_ROOT/log/.
fi

if [ "$isUnInstallOption" = "true" ] ; then
 # Check that the ifix backup files are found
 echo "Ifix_LI72432: Checking for ifix backup files ..."
  if [ -f $WVS_ROOT/ifix/LI72432/wvsapp.ear.bak ] ; then
      echo "Ifix_LI72432: Ifix backup files found.. proceeding to un-install ifix"

      
      echo "Ifix_LI72432: Stopping WebSphere Application Server"
      $WAS_HOME/bin/stopServer.sh server1
      echo $?
      if [ "$?" = "246" -o "$?" = "0" ] ; then
         echo "Ifix_LI72432: Application Server stopped successful, proceeding to un-install ifix"
      else
         echo "Ifix_LI72432: Application Server reported failure during stopping. Ifix installation will not continue"
         rm -rf $WVS_ROOT/ifix/LI72432
         exit -1
      fi
      
	  # Backup SIV config files ----------------------------------------------------
      echo "Ifix_LI72432: Backing up SIV config files..."
      mkdir -p $WVS_ROOT/ifix/LI72432/confbck >> $WVS_ROOT/log/LI72432.log
      cp -fp $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsweb.war/WEB-INF/ibm-web-bnd.xmi $WVS_ROOT/ifix/LI72432/confbck >> $WVS_ROOT/log/LI72432.log
      cp -fp $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsweb.war/WEB-INF/web.xml $WVS_ROOT/ifix/LI72432/confbck >> $WVS_ROOT/log/LI72432.log
      cp -fp $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsejb.jar/META-INF/ibm-ejb-jar-bnd.xmi $WVS_ROOT/ifix/LI72432/confbck >> $WVS_ROOT/log/LI72432.log
      cp -fp $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsejb.jar/META-INF/ejb-jar.xml $WVS_ROOT/ifix/LI72432/confbck >> $WVS_ROOT/log/LI72432.log
      echo "Ifix_LI72432: SIV config backup complete."
      # ----------------------------------------------------------------------------
	  
      cp -fp $WVS_ROOT/ifix/LI72432/wvsapp.ear.bak $WVS_ROOT/ear/wvsapp.ear
      cp -fp $WVS_ROOT/ifix/LI72432/libibmgram.so.bak  $WVS_ROOT/ViaVoice/bin/libibmgram.so
	  
      echo "Ifix_LI72432: Starting WebSphere Application Server"
      $WAS_HOME/bin/startServer.sh server1 -quiet
      if [ "$?" = "111" -o "$?" = "0" ] ; then
         echo "Ifix_LI72432: Application Server started successful, proceeding to uninstall ifix"
      else
         echo "Ifix_LI72432: Application Server reported failure during starting. Ifix uninstallation was not successful. Please contact support"
         exit -1
      fi
       
      echo "Ifix_LI72432: Stopping  WebSphere Voice Server"
      $WAS_HOME/bin/wsadmin.sh -f $WVS_ROOT/ifix/LI72432/stopVoiceServer.jacl $thisHostname
      errorsduringinstall=$?
          
      echo "Ifix_LI72432: Updating WebSphere Voice Server J2EE Application"
      $WAS_HOME/bin/wsadmin.sh -f $WVS_ROOT/.package/installEar.jacl $WVS_ROOT/ear wvsapp WVS5.1-$thisHostname $thisHostname
      errorsduringinstall=$?
      
	   # Restore config files -------------------------------------------------------
      echo "Ifix_LI72432: Restoring SIV config files..."
      cp -fp $WVS_ROOT/ifix/LI72432/confbck/ibm-web-bnd.xmi  $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsweb.war/WEB-INF >> $WVS_ROOT/log/LI72432.log
      cp -fp $WVS_ROOT/ifix/LI72432/confbck/web.xml $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsweb.war/WEB-INF >> $WVS_ROOT/log/LI72432.log
      cp -fp $WVS_ROOT/ifix/LI72432/confbck/ibm-ejb-jar-bnd.xmi $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsejb.jar/META-INF >> $WVS_ROOT/log/LI72432.log
      cp -fp $WVS_ROOT/ifix/LI72432/confbck/ejb-jar.xml $WAS_HOME/config/cells/$WAS_CELL/applications/WVS5.1-$WAS_NODE.ear/deployments/WVS5.1-$WAS_NODE/wvsejb.jar/META-INF >> $WVS_ROOT/log/LI72432.log
	  
      rm -rf $WVS_ROOT/ifix/LI72432/confbck >> $WVS_ROOT/log/LI72432.log
      echo "Ifix_LI72432: SIV config files restored."
      # ----------------------------------------------------------------------------
	   
      if [ $errorsduringinstall = "0" ] ; then
        echo "Ifix_LI72432: Ifix is now uninstalled, please reboot the system. Remove "
        echo "Ifix_LI72432:  the $WVS_ROOT/ifix/LI72432 directory before attempting a subsequent install of this ifix."
      else
        echo "Ifix_LI72432: Ifix uninstallation was not successful. Please contact support. "
      fi
    
  else
    echo "Ifix_LI72432: Ifix backup files missing, uninstall not performed"
  fi
fi
exit $?
